@@ -67,10 +67,10 @@ void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
     foreach (QObject *child, item->children()) {
         //find for the needed property of Layout: minimum/maximum/preferred sizes and fillWidth/fillHeight
         if (child->property("minimumWidth").isValid() && child->property("minimumHeight").isValid() &&
-            child->property("preferredWidth").isValid() && child->property("preferredHeight").isValid() &&
-            child->property("maximumWidth").isValid() && child->property("maximumHeight").isValid() &&
-            child->property("fillWidth").isValid() && child->property("fillHeight").isValid()
-        ) {
+                child->property("preferredWidth").isValid() && child->property("preferredHeight").isValid() &&
+                child->property("maximumWidth").isValid() && child->property("maximumHeight").isValid() &&
+                child->property("fillWidth").isValid() && child->property("fillHeight").isValid()
+           ) {
             layout = child;
         }
     }
@@ -97,10 +97,10 @@ void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
     foreach (QObject *child, q->children()) {
         //find for the needed property of Layout: minimum/maximum/preferred sizes and fillWidth/fillHeight
         if (child->property("minimumWidth").isValid() && child->property("minimumHeight").isValid() &&
-            child->property("preferredWidth").isValid() && child->property("preferredHeight").isValid() &&
-            child->property("maximumWidth").isValid() && child->property("maximumHeight").isValid() &&
-            child->property("fillWidth").isValid() && child->property("fillHeight").isValid()
-        ) {
+                child->property("preferredWidth").isValid() && child->property("preferredHeight").isValid() &&
+                child->property("maximumWidth").isValid() && child->property("maximumHeight").isValid() &&
+                child->property("fillWidth").isValid() && child->property("fillHeight").isValid()
+           ) {
             ownLayout = child;
         }
     }
@@ -121,24 +121,24 @@ void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
 
     //Here we can't use the new connect syntax because we can't link against QtQuick layouts
     QObject::connect(layout, SIGNAL(minimumWidthChanged()),
-            q, SLOT(minimumWidthChanged()));
+                     q, SLOT(minimumWidthChanged()));
     QObject::connect(layout, SIGNAL(minimumHeightChanged()),
-            q, SLOT(minimumHeightChanged()));
+                     q, SLOT(minimumHeightChanged()));
 
     QObject::connect(layout, SIGNAL(preferredWidthChanged()),
-            q, SLOT(preferredWidthChanged()));
+                     q, SLOT(preferredWidthChanged()));
     QObject::connect(layout, SIGNAL(preferredHeightChanged()),
-            q, SLOT(preferredHeightChanged()));
+                     q, SLOT(preferredHeightChanged()));
 
     QObject::connect(layout, SIGNAL(maximumWidthChanged()),
-            q, SLOT(maximumWidthChanged()));
+                     q, SLOT(maximumWidthChanged()));
     QObject::connect(layout, SIGNAL(maximumHeightChanged()),
-            q, SLOT(maximumHeightChanged()));
+                     q, SLOT(maximumHeightChanged()));
 
     QObject::connect(layout, SIGNAL(fillWidthChanged()),
-            q, SLOT(fillWidthChanged()));
+                     q, SLOT(fillWidthChanged()));
     QObject::connect(layout, SIGNAL(fillHeightChanged()),
-            q, SLOT(fillHeightChanged()));
+                     q, SLOT(fillHeightChanged()));
 
     representationLayout = layout;
     AppletQuickItemPrivate::ownLayout = ownLayout;
@@ -191,16 +191,16 @@ QObject *AppletQuickItemPrivate::createFullRepresentationItem()
         emit q->fullRepresentationChanged(fullRepresentation.data());
     }
 
-
     if (!fullRepresentationItem) {
         return 0;
     }
 
     QQuickItem *graphicsObj = qobject_cast<QQuickItem *>(fullRepresentationItem.data());
-    QObject::connect (graphicsObj, &QQuickItem::widthChanged, [=]() {
+
+    QObject::connect(graphicsObj, &QQuickItem::widthChanged, [ = ]() {
         fullRepresentationResizeTimer.start();
     });
-    QObject::connect (graphicsObj, &QQuickItem::heightChanged, [=]() {
+    QObject::connect(graphicsObj, &QQuickItem::heightChanged, [ = ]() {
         fullRepresentationResizeTimer.start();
     });
 
@@ -245,20 +245,20 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
     } else {
         if (switchWidth > 0 && switchHeight > 0) {
             full = q->width() > switchWidth && q->height() > switchHeight;
-        //if a size to switch wasn't set, determine what representation to always chose
+            //if a size to switch wasn't set, determine what representation to always chose
         } else {
             //preferred representation set?
             if (preferredRepresentation) {
                 full = preferredRepresentation.data() == fullRepresentation.data();
-            //Otherwise, base on FormFactor
+                //Otherwise, base on FormFactor
             } else {
                 full = (applet->formFactor() != Plasma::Types::Horizontal && applet->formFactor() != Plasma::Types::Vertical);
             }
         }
 
         if ((full && fullRepresentationItem && fullRepresentationItem.data() == currentRepresentationItem.data()) ||
-            (!full && compactRepresentationItem && compactRepresentationItem.data() == currentRepresentationItem.data())
-        ) {
+                (!full && compactRepresentationItem && compactRepresentationItem.data() == currentRepresentationItem.data())
+           ) {
             return;
         }
     }
@@ -271,6 +271,7 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             //unwire with the expander
             if (compactRepresentationExpanderItem) {
                 compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant());
+                compactRepresentationExpanderItem.data()->setProperty("compactRepresentation", QVariant());
                 compactRepresentationExpanderItem.data()->setProperty("visible", false);
             }
 
@@ -286,18 +287,13 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
                 compactRepresentationItem.data()->setProperty("visible", false);
             }
 
-            if (compactRepresentationExpanderItem) {
-                compactRepresentationExpanderItem.data()->setProperty("compactRepresentation", QVariant());
-                compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant());
-            }
-
             currentRepresentationItem = item;
             connectLayoutAttached(item);
             expanded = true;
             emit q->expandedChanged(true);
         }
 
-    //Icon
+        //Icon
     } else {
         QQuickItem *compactItem = qobject_cast<QQuickItem *>(createCompactRepresentationItem());
         QQuickItem *compactExpanderItem = qobject_cast<QQuickItem *>(createCompactRepresentationExpanderItem());
@@ -324,7 +320,7 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
 
             currentRepresentationItem = compactItem;
             connectLayoutAttached(compactItem);
-            
+
             expanded = false;
             emit q->expandedChanged(false);
         }
@@ -371,9 +367,6 @@ void AppletQuickItemPrivate::fillHeightChanged()
     propagateSizeHint("fillHeight");
 }
 
-
-
-
 AppletQuickItem::AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent)
     : QQuickItem(parent),
       d(new AppletQuickItemPrivate(applet, this))
@@ -387,22 +380,21 @@ AppletQuickItem::AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent)
 
     d->compactRepresentationCheckTimer.setSingleShot(true);
     d->compactRepresentationCheckTimer.setInterval(250);
-    connect (&d->compactRepresentationCheckTimer, SIGNAL(timeout()),
-             this, SLOT(compactRepresentationCheck()));
+    connect(&d->compactRepresentationCheckTimer, SIGNAL(timeout()),
+            this, SLOT(compactRepresentationCheck()));
     d->compactRepresentationCheckTimer.start();
 
     d->fullRepresentationResizeTimer.setSingleShot(true);
     d->fullRepresentationResizeTimer.setInterval(250);
-    connect (&d->fullRepresentationResizeTimer, &QTimer::timeout,
-             [=]() {
-                KConfigGroup cg = d->applet->config();
-                cg = KConfigGroup(&cg, "PopupApplet");
-                cg.writeEntry("DialogWidth", d->fullRepresentationItem.data()->property("width").toInt());
-                cg.writeEntry("DialogHeight", d->fullRepresentationItem.data()->property("height").toInt());
-            }
-    );
-
-
+    connect(&d->fullRepresentationResizeTimer, &QTimer::timeout,
+    [ = ]() {
+        if (!d->applet->isContainment()) {
+            KConfigGroup cg = d->applet->config();
+            cg = KConfigGroup(&cg, "PopupApplet");
+            cg.writeEntry("DialogWidth", d->fullRepresentationItem.data()->property("width").toInt());
+            cg.writeEntry("DialogHeight", d->fullRepresentationItem.data()->property("height").toInt());
+        }
+    });
 
     d->qmlObject = new KDeclarative::QmlObject(this);
     d->qmlObject->setInitializationDelayed(true);
@@ -422,7 +414,7 @@ AppletQuickItem::~AppletQuickItem()
     AppletQuickItemPrivate::s_rootObjects.remove(d->qmlObject->engine());
 }
 
- AppletQuickItem *AppletQuickItem::qmlAttachedProperties(QObject *object)
+AppletQuickItem *AppletQuickItem::qmlAttachedProperties(QObject *object)
 {
     //at the moment of the attached object creation, the root item is the only one that hasn't a parent
     //only way to avoid creation of this attached for everybody but the root item
@@ -451,23 +443,28 @@ void AppletQuickItem::init()
     //Initialize the main QML file
     QQmlEngine *engine = d->qmlObject->engine();
 
-    PackageUrlInterceptor *interceptor = new PackageUrlInterceptor(engine, d->applet->package());
-    interceptor->addAllowedPath(d->coronaPackage.path());
-    engine->setUrlInterceptor(interceptor);
+    if (d->applet->package().isValid()) {
+        PackageUrlInterceptor *interceptor = new PackageUrlInterceptor(engine, d->applet->package());
+        interceptor->addAllowedPath(d->coronaPackage.path());
+        engine->setUrlInterceptor(interceptor);
+    }
 
     d->qmlObject->setSource(QUrl::fromLocalFile(d->applet->package().filePath("mainscript")));
 
     if (!engine || !engine->rootContext() || !engine->rootContext()->isValid() || d->qmlObject->mainComponent()->isError()) {
         QString reason;
-        foreach (QQmlError error, d->qmlObject->mainComponent()->errors()) {
-            reason += error.toString()+'\n';
+        if (d->applet->package().isValid()) {
+            foreach (QQmlError error, d->qmlObject->mainComponent()->errors()) {
+                reason += error.toString() + '\n';
+            }
+            reason = i18n("Error loading QML file: %1", reason);
+        } else {
+            reason = i18n("Error loading Applet: package inexistent. %1", applet()->launchErrorMessage());
         }
-        reason = i18n("Error loading QML file: %1", reason);
 
         d->qmlObject->setSource(QUrl::fromLocalFile(d->coronaPackage.filePath("appleterror")));
         d->qmlObject->completeInitialization();
 
-
         //even the error message QML may fail
         if (d->qmlObject->mainComponent()->isError()) {
             return;
@@ -490,6 +487,16 @@ void AppletQuickItem::init()
     if (!d->fullRepresentation) {
         d->fullRepresentation = d->qmlObject->mainComponent();
         d->fullRepresentationItem = d->qmlObject->rootObject();
+
+        if (d->qmlObject->rootObject()) {
+            QQuickItem *graphicsObj = qobject_cast<QQuickItem *>(d->fullRepresentationItem.data());
+            QObject::connect(graphicsObj, &QQuickItem::widthChanged, [ = ]() {
+                d->fullRepresentationResizeTimer.start();
+            });
+            QObject::connect(graphicsObj, &QQuickItem::heightChanged, [ = ]() {
+                d->fullRepresentationResizeTimer.start();
+            });
+        }
         emit fullRepresentationChanged(d->fullRepresentation.data());
     }
 
@@ -573,7 +580,6 @@ void AppletQuickItem::setCompactRepresentation(QQmlComponent *component)
     emit compactRepresentationChanged(component);
 }
 
-
 QQmlComponent *AppletQuickItem::fullRepresentation()
 {
     return d->fullRepresentation.data();
@@ -623,7 +629,26 @@ void AppletQuickItem::setExpanded(bool expanded)
 
     if (expanded) {
         d->createFullRepresentationItem();
-        d->compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant::fromValue(d->createFullRepresentationItem()));
+        if (!d->applet->isContainment() &&
+                (!d->preferredRepresentation ||
+                 d->preferredRepresentation.data() != d->fullRepresentation.data())) {
+            d->createCompactRepresentationExpanderItem();
+        }
+
+        KConfigGroup cg = d->applet->config();
+        cg = KConfigGroup(&cg, "PopupApplet");
+        const int width = cg.readEntry("DialogWidth", -1);
+        const int height = cg.readEntry("DialogHeight", -1);
+        if (width > 0  && height > 0) {
+            d->fullRepresentationItem.data()->setProperty("width", width);
+            d->fullRepresentationItem.data()->setProperty("height", height);
+        }
+
+        if (d->compactRepresentationExpanderItem) {
+            d->compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant::fromValue(d->createFullRepresentationItem()));
+        } else {
+            d->fullRepresentationItem.data()->setProperty("parent", QVariant::fromValue(this));
+        }
     }
 
     d->expanded = expanded;
@@ -632,7 +657,6 @@ void AppletQuickItem::setExpanded(bool expanded)
 
 ////////////Internals
 
-
 KDeclarative::QmlObject *AppletQuickItem::qmlObject()
 {
     return d->qmlObject;
