@@ -26,6 +26,7 @@
 #include <kactioncollection.h>
 #include <kservicetypetrader.h>
 #include <kdesktopfile.h>
+#include <KConfigLoader>
 
 #include <QDebug>
 #include <QQmlExpression>
@@ -33,7 +34,6 @@
 #include <QQmlProperty>
 #include <QSignalMapper>
 
-#include <Plasma/ConfigLoader>
 #include <Plasma/PluginLoader>
 
 QHash<QObject *, WallpaperInterface *> WallpaperInterface::s_rootObjects = QHash<QObject *, WallpaperInterface *>();
@@ -58,7 +58,9 @@ WallpaperInterface::WallpaperInterface(ContainmentInterface *parent)
 
 WallpaperInterface::~WallpaperInterface()
 {
-    s_rootObjects.remove(m_qmlObject->engine());
+    if (m_qmlObject) {
+        s_rootObjects.remove(m_qmlObject->engine());
+    }
 }
 
 KPluginInfo::List WallpaperInterface::listWallpaperInfoForMimetype(const QString &mimetype, const QString &formFactor)
@@ -78,12 +80,17 @@ Plasma::Package WallpaperInterface::package() const
     return m_pkg;
 }
 
+QString WallpaperInterface::pluginName() const
+{
+    return m_wallpaperPlugin;
+}
+
 KDeclarative::ConfigPropertyMap *WallpaperInterface::configuration() const
 {
     return m_configuration;
 }
 
-Plasma::ConfigLoader *WallpaperInterface::configScheme()
+KConfigLoader *WallpaperInterface::configScheme()
 {
     if (!m_configLoader) {
         //FIXME: do we need "mainconfigxml" in wallpaper packagestructures?
@@ -93,10 +100,10 @@ Plasma::ConfigLoader *WallpaperInterface::configScheme()
         cfg = KConfigGroup(&cfg, "Wallpaper");
 
         if (xmlPath.isEmpty()) {
-            m_configLoader = new Plasma::ConfigLoader(&cfg, 0);
+            m_configLoader = new KConfigLoader(cfg, 0);
         } else {
             QFile file(xmlPath);
-            m_configLoader = new Plasma::ConfigLoader(&cfg, &file);
+            m_configLoader = new KConfigLoader(cfg, &file);
         }
     }
 
@@ -105,12 +112,13 @@ Plasma::ConfigLoader *WallpaperInterface::configScheme()
 
 void WallpaperInterface::syncWallpaperPackage()
 {
-    if (m_wallpaperPlugin == m_containmentInterface->containment()->wallpaper()) {
+    if (m_wallpaperPlugin == m_containmentInterface->containment()->wallpaper() &&
+            m_qmlObject->rootObject()) {
         return;
     }
 
     m_wallpaperPlugin = m_containmentInterface->containment()->wallpaper();
-    
+
     if (!m_qmlObject) {
         m_qmlObject = new KDeclarative::QmlObject(this);
         s_rootObjects[m_qmlObject->engine()] = this;
@@ -119,6 +127,10 @@ void WallpaperInterface::syncWallpaperPackage()
 
     m_actions->clear();
     m_pkg = Plasma::PluginLoader::self()->loadPackage("Plasma/Wallpaper");
+    if (!m_pkg.isValid()) {
+        qWarning() << "Error loading the wallpaper, no valid package loaded";
+        return;
+    }
     m_pkg.setPath(m_wallpaperPlugin);
 
     m_configLoader->deleteLater();
@@ -129,14 +141,13 @@ void WallpaperInterface::syncWallpaperPackage()
         m_configuration = new KDeclarative::ConfigPropertyMap(configScheme(), this);
     }
 
-    
     m_qmlObject->setSource(QUrl::fromLocalFile(m_pkg.filePath("mainscript")));
     m_qmlObject->engine()->rootContext()->setContextProperty("wallpaper", this);
     m_qmlObject->completeInitialization();
 
     if (m_qmlObject->mainComponent() &&
-        m_qmlObject->rootObject() &&
-        !m_qmlObject->mainComponent()->isError()) {
+            m_qmlObject->rootObject() &&
+            !m_qmlObject->mainComponent()->isError()) {
         m_qmlObject->rootObject()->setProperty("z", -1000);
         m_qmlObject->rootObject()->setProperty("parent", QVariant::fromValue(this));
 
@@ -159,7 +170,7 @@ void WallpaperInterface::syncWallpaperPackage()
     emit configurationChanged();
 }
 
-QList<QAction*> WallpaperInterface::contextualActions() const
+QList<QAction *> WallpaperInterface::contextualActions() const
 {
     return m_actions->actions();
 }
@@ -174,7 +185,7 @@ bool WallpaperInterface::supportsMimetype(const QString &mimetype) const
 void WallpaperInterface::setUrl(const QUrl &url)
 {
     if (m_qmlObject->rootObject()) {
-         QMetaObject::invokeMethod(m_qmlObject->rootObject(), QString("setUrl").toLatin1(), Qt::DirectConnection, Q_ARG(QVariant, QVariant::fromValue(url)));
+        QMetaObject::invokeMethod(m_qmlObject->rootObject(), QString("setUrl").toLatin1(), Qt::DirectConnection, Q_ARG(QVariant, QVariant::fromValue(url)));
     }
 }
 
@@ -234,7 +245,7 @@ QAction *WallpaperInterface::action(QString name) const
 void WallpaperInterface::executeAction(const QString &name)
 {
     if (m_qmlObject->rootObject()) {
-         QMetaObject::invokeMethod(m_qmlObject->rootObject(), QString("action_" + name).toLatin1(), Qt::DirectConnection);
+        QMetaObject::invokeMethod(m_qmlObject->rootObject(), QString("action_" + name).toLatin1(), Qt::DirectConnection);
     }
 }
 
